@@ -39,18 +39,10 @@ def shift_channels(df , TSHIFT, TWIN, x,y):
     return df
 
 
-def fastread(filename, x=0, y=1, batch = 0, read_last=0):
+def only_read( filename, x=0, y=1, batch=0, read_last=0):
     """
-    use: ./bin_readvme fast run0023_20200220_144753.asc 0 1  --read_last 500
+    reads the filename to DF and returns it
     """
-    TSHIFT = 20 # 10 seems ok, 20 is safe (200ns)
-    TWIN = 2*TSHIFT
-    CHAN0=x
-    CHAN1=y
-    ENE_0="chan_"+str(CHAN0)
-    ENE_1="chan_"+str(CHAN1)
-    MAXROWS = 1000*1000*35
-
     basename = os.path.basename(filename)
     basename = os.path.splitext(basename)[0]
     startd = basename.split("_")[1]
@@ -78,18 +70,41 @@ def fastread(filename, x=0, y=1, batch = 0, read_last=0):
 
     print("D... basename = ",basename)
     if read_last>0:
-        df = pd.read_table( filename, names=['time',ENE_0,'x','ch','y'],
+        df = pd.read_table( filename, names=['time',"e",'x','ch','y'],
                         sep = "\s+", comment="#",
                         nrows = read_last,
                         skiprows=count-read_last)
                         #nrows = MAXROWS,
                         #skiprows=MAXROWS*batch)
     else:
-        df = pd.read_table( filename, names=['time',ENE_0,'x','ch','y'],
+        df = pd.read_table( filename, names=['time',"e",'x','ch','y'],
                         sep = "\s+", comment="#",
                         nrows = MAXROWS,
                         skiprows=MAXROWS*batch)
 
+    return df
+
+
+def fastread(filename, x=0, y=1, batch = 0, read_last=0, df = None, plot = False):
+    """
+    use: ./bin_readvme fast run0023_20200220_144753.asc 0 1  --read_last 500
+    """
+    TSHIFT = 20 # 10 seems ok, 20 is safe (200ns)
+    TWIN = 2*TSHIFT
+    CHAN0=x
+    CHAN1=y
+    ENE_0="chan_"+str(CHAN0)
+    ENE_1="chan_"+str(CHAN1)
+    MAXROWS = 1000*1000*35
+
+
+    if df is None:
+        df = only_read(filename, x,y,batch, read_last)
+
+    # energy is marked "e"
+    df = df.rename(columns={"e":ENE_0})
+
+
     if (len(df)<MAXROWS):
         print("X... END OF FILE REACHED ***")
         CONTINUE = False
@@ -141,14 +156,14 @@ def fastread(filename, x=0, y=1, batch = 0, read_last=0):
         print(f"D... only {MAXROWS} read")
         print("X...  INCOMPLETE FILE, TRY TO READ batch=", batch+1)
 
-    df2.plot.scatter(x=ENE_0,
-                y=ENE_1,
+    if plot:
+        df2.plot.scatter(x=ENE_0,  y=ENE_1,
                      ylim=(0, 2000), xlim=(0,2000),
                      s=.01);
-    plt.show()
+        plt.show()
+        return
 
-
-    return
+    return df2
 
 
 
@@ -259,4 +274,5 @@ def main1(filename,  od=0, do=9999999 , chan=1):
 
 
 if __name__=="__main__":
+    print("D... fastread can be called too, from bin_readvme")
     Fire(main1)
